// DO NOT EDIT -- generated by mk-ops.awk
#if ! defined (octave_mx_cm_dm_h)
#define octave_mx_cm_dm_h 1
#include "octave-config.h"
#include "CMatrix.h"
#include "dDiagMatrix.h"
  extern OCTAVE_API ComplexMatrix operator + (const ComplexMatrix&, const DiagMatrix&);
  extern OCTAVE_API ComplexMatrix operator - (const ComplexMatrix&, const DiagMatrix&);
  extern OCTAVE_API ComplexMatrix operator * (const ComplexMatrix&, const DiagMatrix&);
#endif
