// DO NOT EDIT -- generated by mk-ops.awk
#if ! defined (octave_mx_m_dm_h)
#define octave_mx_m_dm_h 1
#include "octave-config.h"
#include "dMatrix.h"
#include "dDiagMatrix.h"
  extern OCTAVE_API Matrix operator + (const Matrix&, const DiagMatrix&);
  extern OCTAVE_API Matrix operator - (const Matrix&, const DiagMatrix&);
  extern OCTAVE_API Matrix operator * (const Matrix&, const DiagMatrix&);
#endif
